]> granicus.if.org Git - nethack/commitdiff
yet another spelling error
authorcohrs <cohrs>
Sun, 27 Apr 2003 15:10:46 +0000 (15:10 +0000)
committercohrs <cohrs>
Sun, 27 Apr 2003 15:10:46 +0000 (15:10 +0000)
"undigestable" -> "indigestible"

src/eat.c
src/mon.c

index 03b46b7051412638a3dc32f66ae6c520c62d7ddf..82c0724b2e62b78232094acf68cd54647c0f03f9 100644 (file)
--- a/src/mon.c
+++ b/src/mon.c
@@ -640,7 +640,7 @@ meatmetal(mtmp)
                        pline("%s spits %s out in disgust!",
                              Monnam(mtmp), distant_name(otmp,doname));
                    }
-               /* KMH -- Don't eat undigestable/choking objects */
+               /* KMH -- Don't eat indigestible/choking objects */
                } else if (otmp->otyp != AMULET_OF_STRANGULATION &&
                                otmp->otyp != RIN_SLOW_DIGESTION) {
                    if (cansee(mtmp->mx,mtmp->my) && flags.verbose)
--- a/src/eat.c
+++ b/src/eat.c
@@ -1892,9 +1892,9 @@ doeat()           /* generic "eat" command funtion (see cmd.c) */
                stackobj(otmp);
                return 1;
        }
/* KMH -- Slow digestion is... undigestable */
        if (otmp->otyp == RIN_SLOW_DIGESTION) {
-               pline("This ring is undigestable!");
+               pline("This ring is indigestible!");
                (void) rottenfood(otmp);
                if (otmp->dknown && !objects[otmp->otyp].oc_name_known
                                && !objects[otmp->otyp].oc_uname)
@@ -1892,9 +1892,9 @@ doeat()           /* generic "eat" command funtion (see cmd.c) */
                return 1;
        }
-       /* KMH -- Slow digestion is... undigestable */
+       /* KMH -- Slow digestion is... indigestible */
        if (otmp->otyp == RIN_SLOW_DIGESTION) {
index dc003880063d6df9afff9b1af08fcc43d0a6febe..72c81f8e4dd7e8abb42854c5f5ec301111b26387 100644 (file)